jaraco.pmxbot
=============

Plugins for `pmxbot <https://pypi.python.org/pypi/pmxbot>`_ by jaraco.

Bookmarklet
-----------

jaraco.pmxbot provides a bookmarklet
for readily sending messages to the pmxbot HTTP interface. To install it,
just open /bookmarklet in the API service. It will present a link.
Option-click the link and add it to your bookmarks. Give it a name like
"Send to pmxbot".

To use the bookmarklet, browse to any web page, then select the bookmarklet.
You will be prompted with a dialog with a channel and message. Specify the
channel and optionally edit the message. Then hit Enter or click Submit and
that message will be broadcast on the channel indicated.
